;; Generated package description from track-changes.el  -*- no-byte-compile: t -*-
(define-package "track-changes" "1.1.0.20240417.105711" "API to react to buffer modifications" '((emacs "24")) :commit "0dbd9ed04660152276696e462359204a45ca933d" :url "https://elpa.gnu.org/packages/track-changes.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca"))
